(***********************************************************************)
(*                                                                     *)
(*                               Grimage                               *)
(*                                                                     *)
(*                           Graphics image                            *)
(*                                                                     *)
(*               EPI Pomdapi, INRIA Paris - Rocquencourt               *)
(*                                                                     *)
(*  Copyright 2014-2014 INRIA.                                         *)
(*  Institut National de Recherche en Informatique et en Automatique.  *)
(*  All rights reserved. This file is distributed only by permission.  *)
(*                                                                     *)
(*  Pierre Weis <Pierre.Weis@inria.fr>                                 *)
(*                                                                     *)
(***********************************************************************)

(* $Id: load_all.ml,v 1.5 2014/02/27 16:47:02 fclement Exp $ *)

(** Usage: from the very directory that contains this file, launch a
toplevel system which contains the Caml [Graphics] library, then
execute the following phrase:

    #use "load_all.ml";;

This will compile and load the Grimage library into the toplevel system.

Notes:

- In Unix, a toplevel system which contains the Caml [Graphics] library,
is obtained with

    $ ocaml graphics.cma

- In Windows, the interactive application already contains the
[Graphics] library.

*)

let compile f =
 match Sys.command ("ocamlc -c " ^ f) with
 | 0 -> ()
 | _ -> failwith ("Cannot compile " ^ f);;

let compile_interface f =
 compile (f ^ ".mli");;

let compile_implementation f =
 compile (f ^ ".ml");;

let compile_module f =
 compile_interface f;
 compile_implementation f;;

compile_interface "generic_image";;
open Generic_image;;

compile_module "version";;
#load "version.cmo";;
open Version;;

compile_module "colors";;
#load "colors.cmo";;
open Colors;;

compile_module "colormapping";;
#load "colormapping.cmo";;
open Colormapping;;

compile_module "pixmap";;
#load "pixmap.cmo";;
open Pixmap;;

compile_module "ppm";;
#load "ppm.cmo";;
open Ppm;;

compile_module "bmp";;
#load "bmp.cmo";;
open Bmp;;

compile_module "grimage";;
#load "grimage.cmo";;
open Grimage;;
